# Generated by Django 4.2.13 on 2024-05-27 10:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0106_remove_homestationfilter_constellations_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='homestationfilter',
            old_name='structures',
            new_name='evelocation',
        ),
    ]
