@keyframes spin {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(359deg);
  }
}

.glyphicon-refresh-animate {
  -animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
}

.flex-image-text {
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
  justify-content: space-evenly;
  align-items: center;
  align-content: center;
}

.padded-label {
  margin: 5px;
}
