# Generated by Django 4.2.9 on 2024-02-12 11:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0101_corporatecontract_corporatecontractitem'),
    ]

    operations = [
        migrations.AddField(
            model_name='corporationaudit',
            name='last_change_contracts',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='corporationaudit',
            name='last_update_contracts',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
