# Generated by Django 4.0.10 on 2023-11-25 08:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0095_lastloginfilter_main_corp_only_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='rolefilter',
            name='main_only',
            field=models.BooleanField(default=False),
        ),
    ]
