# Generated by Django 4.0.7 on 2022-09-18 07:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0076_remove_characterasset_corptools_c_type_id_05ccc2_idx_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='fullyloadedfilter',
            name='reversed_logic',
            field=models.BooleanField(
                default=False, help_text='If set all members WITHOUT audit fully loaded will pass the test.'),
        ),
    ]
