{% load humanize %}
{% load i18n %}
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center">{% translate "Capital Ships" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in capital_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center ">{% translate "Sub-Capital Ships" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in subcap_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center">{% translate "Notable Others Assets" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in noteable_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center">{% translate "BPO's" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in bpo_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center">{% translate "Structures" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in structure_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
<div class="col-md-4 col-xs-12 col-sm-12">
    <div class="panel panel-primary">
        <div class="panel-heading text-center">{% translate "Rest" %}</div>
        <div class="panel-body pannel-hieght-locked scroll-bar-narrow">
            <table class="table">
                {% for g in remaining_asset_groups %}
                    <tr>
                        <td class="">{{ g.grp_name }}</td>
                        <td class="text-right">
                            <span class="badge">{{ g.grp_total|intcomma }}</span>
                        </td>
                    </tr>
                {% endfor %}
            </table>
        </div>
    </div>
</div>
