# Generated by Django 4.0.7 on 2022-10-05 05:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0077_fullyloadedfilter_reversed_logic'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='characterwalletjournalentry',
            index=models.Index(
                fields=['date'], name='corptools_c_date_aebcea_idx'),
        ),
        migrations.AddIndex(
            model_name='characterwalletjournalentry',
            index=models.Index(fields=['entry_id'],
                               name='corptools_c_entry_i_d9e191_idx'),
        ),
        migrations.AddIndex(
            model_name='characterwalletjournalentry',
            index=models.Index(fields=['ref_type'],
                               name='corptools_c_ref_typ_fe0ec9_idx'),
        ),
        migrations.AddIndex(
            model_name='corporationwalletjournalentry',
            index=models.Index(
                fields=['date'], name='corptools_c_date_ca15ac_idx'),
        ),
        migrations.AddIndex(
            model_name='corporationwalletjournalentry',
            index=models.Index(fields=['entry_id'],
                               name='corptools_c_entry_i_09f70e_idx'),
        ),
        migrations.AddIndex(
            model_name='corporationwalletjournalentry',
            index=models.Index(fields=['ref_type'],
                               name='corptools_c_ref_typ_326ddd_idx'),
        ),
    ]
