# Generated by Django 2.2.12 on 2020-09-15 11:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0032_auto_20200901_0537'),
    ]

    operations = [
        migrations.AddField(
            model_name='skilllist',
            name='order_weight',
            field=models.IntegerField(default=0),
        ),
    ]
