* {
  margin: 0;
  padding: 0;
}

.flex {
  display: flex;
  height: 80px;
  align-items: center;
}

.child {
  margin-right: 20px;
}

.child-end {
  margin-left: auto;
}

.fill-width {
  overflow: auto;
}

.float-left {
  float: left; /* [1] */
}

.flex-container {
  display: flex;
  align-items: center;
  justify-content: center;
  align-content: center;
  flex-wrap: wrap;
  flex-direction: row;
}

.flex-wide {
  justify-content: space-between;
  flex-wrap: nowrap;
}

.flex-wide-child {
  width: 700px;
}

.flex-container-pull-right {
  display: flex;
  align-items: flex-end;
  justify-content: center;
  align-content: center;
  flex-direction: row;
}

.flex-container-vert-fill {
  display: flex;
  align-items: stretch;
  justify-content: center;
  align-content: stretch;
  flex-wrap: wrap;
  flex-direction: column;
}

.flex-child {
  /*width: 33%;*/
  margin: 10px;
}

.flex-body {
  align-items: center;
}

.table-div {
  height: 250px;
  width: 400px;
  overflow-y: auto;
}

.table-div-no-hight {
  height: unset;
}

.table-div-fill {
  width: auto;
}

.table-div::-webkit-scrollbar {
  width: 3; /* Remove scrollbar space */
  background: transparent; /* Optional: just make scrollbar invisible */
}

/* Optional: show position indicator in red */
.table-div::-webkit-scrollbar-thumb {
  background-color: #375a7f4b;
  border-left: 15px solid transparent;
  background-clip: padding-box;
}

.no-wrap {
  white-space: nowrap;
}

.info-hide {
}

@media only screen and (max-width: 1400px) {
  .info-hide {
    display: none;
  }
}

.association-hide {
}

@media only screen and (max-width: 1000px) {
  .association-hide {
    display: none;
  }
}

.flex-label-container {
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
  justify-content: flex-start;
  align-items: stretch;
  align-content: stretch;
}

.flex-label {
  margin: 2px;
}
.flex-select {
  flex: 1;
  margin: 2px;
}

.flex-select-size {
  width: 300px;
}
