.doctrine-button {
  width: 23%;
  margin: 5px;
}

.flex-doctrine-btn-name {
  flex: 5;
}
.flex-doctrine-btn-copy {
  flex: 1;
  border: 2px solid #d9534f;
}
@media only screen and (max-width: 1900px) {
  .doctrine-button {
    width: 30%;
  }
}

@media only screen and (min-width: 1900px) {
  .doctrine-button {
    width: 17%;
  }
}

@media only screen and (max-width: 800px) {
  .doctrine-button {
    width: 100%;
  }
}

.flex-five {
  flex: 5;
  justify-content: space-evenly;
}

.flex-one {
  flex: 1;
}

.doctrine-portrait {
  width: 300px;
  height: 300px;
}
