{% load i18n %}
<div class="col-12 col-xl-8 align-self-stretch p-2">
    <div class="card">
        <div class="card-body">
            <h4 class="card-title text-center" style="text-align: center">{% translatelate 'Characters' %}</h4>
            <div class="card-body">
                <div style="height: 300px;overflow:-moz-scrollbars-vertical;overflow-y:auto;">
                    <a href="/account/characters/add/" class="nav-link" title="{% translate "Add Character" %}"><i class="fas fa-plus"></i><span class="d-lg-none d-md-inline m-2">{% translate "Add Character" %}</span></a>
                </div>
            </div>
        </div>
    </div>
</div>
