# Generated by Django 4.2.13 on 2024-05-27 10:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0107_rename_structures_homestationfilter_evelocation'),
    ]

    operations = [
        migrations.CreateModel(
            name='JumpCloneFilter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('evelocation', models.ManyToManyField(blank=True, help_text='Limit filter to specific Structures', to='corptools.evelocation')),
            ],
            options={
                'verbose_name': 'Smart Filter: Jump Clone',
                'verbose_name_plural': 'Smart Filter: Jump Clone',
            },
        ),
    ]
